"""
RecentNotifications.py
by Jason Conti
February 19, 2010

Applet for viewing recent notifications.
"""

import gtk
import logging
import os.path

from About import show_about
from MessageWindow import MessageWindow
from Monitor import Monitor

class RecentNotifications(object):
  """The main applet wrapper."""
  def __init__(self, applet, iid):
    self._applet = applet

    self._unread_messages = 0

    self._button = gtk.ToggleButton("No Unread Messages")
    self._button.connect("button_press_event", self.do_not_eat_button_press)
    self._button.connect("toggled", self.on_button_toggled)
    self._applet.add(self._button)

    self._applet.setup_menu("""
      <popup name="button3">
        <menuitem name="About" verb="About" _label="_About" pixtype="stock" pixname="gtk-about"/>
      </popup>
      """, [
      ("About", lambda a, b: self.on_show_about(a))
      ])

    self._window = MessageWindow(self)

    self._applet.connect("destroy", self.on_applet_destroyed)
    self._applet.show_all()

    self._monitor = Monitor()
    self._monitor.connect("message-received", self.on_message_received)

  def get_orient(self):
    return self._applet.get_orient()

  def get_origin(self):
    return self._button.get_window().get_origin()

  def get_screen(self):
    return self._button.get_window().get_screen()

  def get_size(self):
    return self._button.get_window().get_size()

  def update_unread_messages(self):
    if self._unread_messages == 0:
      label = "No Unread Messages"
    elif self._unread_messages == 1:
      label = "1 Unread Message"
    else:
      label = str(self._unread_messages) + " Unread Messages"

    self._button.set_label(label)

  # Callbacks

  def do_not_eat_button_press(self, widget, event):
    """Adapted from the GNOME clock applet."""
    if event.button != 1:
      widget.stop_emission("button_press_event")

    return False

  def on_applet_destroyed(self, *args):
    self._monitor.close()

  def on_button_toggled(self, button, *args):
    if button.get_active():
      self._window.show_all()
      self._window.align_with_parent()
    else:
      self._window.hide_all()
      self._unread_messages = 0
      self.update_unread_messages()

  def on_message_received(self, monitor, message):
    self._window.add_message(message)
    self._unread_messages += 1
    self.update_unread_messages()

  def on_show_about(self, *args):
    show_about(self)

